%define tarname   xf86-video-radeonhd
%define moduledir %(pkg-config xorg-server --variable=moduledir)
%define driverdir %{moduledir}/drivers

# Git snapshots are treated slightly different from released source tarballs:
#  * Release: tag is augmented with timestamp
#  * Description contains a few things about the snapshot
#  * Source: snapshots are local files with timestamps, released source
#    tarballs come from ftp.x.org and have no timestamps
#  * ...
# %define snapshot 0
%define snapshot 1

# If generating snapshot, we can add a utility which generates an xinf file.
# This might become interesting at some time in the future, when we are
# confident that we want radeonhd to handle those cards.
%if 0%{snapshot}
# %define generate_xinf 1
%define generate_xinf 0
%endif

%if 0%{snapshot}
%define date 20080301
%define git_commit 8c6d1b46b70ae19fafb5484c238a74cca18d5990
%define alphatag .%{date}git
%define tarball %{tarname}-%{version}-%{date}git
%else
%define tarball %{tarname}-%{version}
%endif

Summary:       Xorg X11 radeonhd driver for AMD GPG r5xx/r6xx Chipsets
Name:          xorg-x11-drv-radeonhd
Version:       1.1.0
Release:       0.7%{?alphatag}%{?dist}.ru

License:       MIT
Group:         User Interface/X Hardware Support
URL:           http://www.x.org/
BuildRoot:     %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%if 0%{snapshot}
# The source for this package was pulled from upstream's git repository.
# (cf. http://gitweb.freedesktop.org/?p=xorg/driver/xf86-video-radeonhd)
# Use the following commands to generate the tarball:
#  sh xorg-x11-drv-radeonhd-snapshot.sh
#  sh xorg-x11-drv-radeonhd-snapshot.sh --update-config
# The latter updates this spec file with the appropriate definition of %date.
# This requires git, automake, autoconf, libtool to be installed.
Source0:       %{tarball}.tar.bz2
%else
Source0:       ftp://ftp.x.org/pub/individual/driver/%{tarball}.tar.bz2
%endif

Source1:       xorg-x11-drv-radeonhd-snapshot.sh
Source2:       xorg-x11-drv-radeonhd-README.fedora

# Needs to be applied while creating dist tarball, but still be in SRPM.
Source11:      %{name}-Generate-xinf-file-for-hwdata-from-rhd_id.c.patch

# 100-199: Fedora adaptations
Patch100:      xorg-x11-drv-radeonhd-Fix-location-of-rhd_conntest-in-msgs.patch

ExcludeArch:   s390 s390x

# EL5 does not have pkgconfig in default buildroot. Does not hurt others.
BuildRequires: pkgconfig

%if 0%{snapshot}
# Required for building rhd_conntest
BuildRequires: pciutils-devel
BuildRequires: zlib-devel
%endif

BuildRequires: xorg-x11-server-sdk  >= 1.1
Requires:      xorg-x11-server-Xorg >= 1.1

# Avoid buggy xrandr (xorg-x11-server-utils is installed anyway for gdm)
%if 0%{?fedora} >= 8
Requires:      xorg-x11-server-utils >= 7.3-2
%endif

# Avoid ABI issue in Fedora 9 and later
%if 0%{?fedora} >= 9
BuildRequires: xorg-x11-server-sdk >= 1.4.99.1
Requires: xorg-x11-server-Xorg >= 1.4.99.1
%else
BuildRequires: xorg-x11-server-sdk < 1.4.99.1
Requires: xorg-x11-server-Xorg < 1.4.99.1
%endif

%description
X.org X11 radeonhd driver for AMD GPG r5xx/r6xx Chipsets.
%if 0%{snapshot}
This package is a snapshot of a work in progress. You may experience
regressions, bugs, errors, broken displays, and other undesirable phenomena.

radeonhd mailing list: http://lists.opensuse.org/radeonhd/

Built from git commit: %{git_commit}
%endif

%prep
%setup -q -n %{tarball}
%if 0%{snapshot}
%patch100 -p1 -b .conntest-docrefs
%endif

%build
%{configure} --with-xorg-module-dir=%{moduledir} --disable-static
%{__make} %{?_smp_mflags}
%{__cp} -p %{SOURCE2} README.fedora
%if 0%{snapshot}
%{__cp} -p utils/conntest/README README.rhd_conntest
%endif
%if 0%{generate_xinf}
./src/print-xinf-data > radeonhd.xinf
%endif

%install
%{__rm} -rf "%{buildroot}"
%{__make} install DESTDIR="%{buildroot}"
%{__rm} -f "%{buildroot}%{driverdir}/radeonhd_drv.la"
%{__install}    -m 0755 -d                          "%{buildroot}/%{_bindir}"
%{__install} -p -m 0755 utils/conntest/rhd_conntest "%{buildroot}/%{_bindir}/rhd_conntest"
%if 0%{generate_xinf}
%{__install}    -m 0755 -d            "%{buildroot}%{_datadir}/hwdata/videoaliases"
%{__install} -p -m 0644 radeonhd.xinf "%{buildroot}%{_datadir}/hwdata/videoaliases"
%endif

%check
%{__make} check || %{__make} check VERBOSE=yes

%clean
%{__rm} -rf "%{buildroot}"

%files
%defattr(-,root,root,-)
%doc README COPYING
%doc README.fedora
%doc ChangeLog
%if 0%{snapshot}
%doc README.rhd_conntest
%{_bindir}/rhd_conntest
%endif
%{driverdir}/radeonhd_drv.so
%{_mandir}/man4/radeonhd.4.gz
%if 0%{generate_xinf}
%{_datadir}/hwdata/videoaliases/radeonhd.xinf
%endif

%changelog
* Sat Mar 01 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.7.20080301git
- Add dependency on xorg server on F9 to prevent ABI compatibility issues (#431176)
- Reflect R5xx partial 2D acceleration support in README.fedora
- New snapshot (upstream commit 8c6d1b46b70ae19fafb5484c238a74cca18d5990):
  - 8c6d1b46: conntest: add new ids.
  - 294cf1f6: Fix test for RS6XX in RHDMCSetup().
  - 1b3f3c9c: Add connector table flag for X1400 (0x7145, 0x1297, 0x3058).
  - a23b1123: Loop over all CRTCs when shutting down memory access.
  - 8432cb08: Add quirk table entry for Diamond Viper Radeon X1650 Pro
  - 5ba5f4b5: Include description for acceleration options.
  - eee9b718: Fix typo in patch adding DradonFlyBSD support.
  - f89bac58: Add support for DragonFlyBSD.
  - 1223e40a: Add debugging to rhd_conntest.c
  - 1e8637b1: Changing R6XX_MC_VM_MISC_OFFSET to R6XX_HDP_NONSURFACE_BASE.
  - 854ce3b2: Make DDC for panels work on MacBook Pro's.
  - 247d4263: Set up GPIO pin HW access for DDC testing in rhd_conntest.
  - 23a47ec0: Restore VGA after restoring the CRTCs.
  - 74eacf3e: Make sure GRAPH and CRTC engine are disabled before changing surface.
  - 2b16734b: Set GPIO pins to be HW driven on R5xx for HW controlled I2C.
  - 2feff5cb: Add wait for memory idle state.
  - e0d58784: Handle LVTMA_TRANSMITTER_ENABLE identically on R5/6xx.
  - 1849092e: Add connector information for a Sapphire Radeon HD 2600 PRO AGP (PnPID: 0x9587:0x1002:0x0028).
  - 7527df07: Revert "PATCH: Report PANEL as disconnected when no modes are available"
  - 3d29d4ce: PATCH: Report PANEL as disconnected when no modes are available
  - cd6a4b89: typo fix in DPI guessing code
  - 1a503c59: Update ObjectID.h
  - 8640be8e: Update atombios.h

* Sat Feb 16 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.6.20080216git
- New snapshot (upstream commit a9af866ae712a0048d374dc640e482d1f4ce8859):
  - a9af866a: Prevent endless loop in connector table parser.
  - 80c7c9e5: Fix device ID for 0x7187, 0x174B, 0x3000 in cards table.
  - bef7f09c: Ask people to not only send in their log file but also to describe their problem.
  - bde5fbbf: Added 'HPD swap' flag for  0x7187, 0x174B, 0x300.
  - 7606be1a: Fully implement the SaveScreen() function.
  - 748de840: VGA: bitten by pScrn->videoRam in kB instead of B again.
  - cbbd54a2: Fix blaning problem in bug #13853.
  - f37d4cb9: Don't make assumptions about DDC clk line on RS690 when AtomBIOS is not available.
  - dc519eb2: Need to include string.h in r5xx_exa.c

* Sun Feb 03 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.5.20080203git
- New snapshot (upstream commit caa10014d115a49a59b4a2aef6ce36a4e615556a):
  - Basic EXA/XAA for R5xx
  - Add PowerColor X1550, PCP X1600 400M/500E, R680 (HD3870 X2)
  - 7cab021c: Improve FB handling
  - e0cfbcd5: Add AccelMethod Option and related handling
  - 5829bff7: TMDSA: Add control value for 71C4
  - 7cb27bca: Add RHD_CARD_FLAG_HPDOFF flag, improve quirk entries for T60p
  - 32d1b4d9: If no EDID is available, assume 96dpi on the first (preferred) mode
  - ad50eaa0: Correct order of mask and value in ROM access code
  - 0f066c20: Implemented PLL functions for CAIL, fixed MC
  - 361ba486: Change heuristics to check for an unPOSTed card
  - 72e7b062: Fix some issues when reading PCI ROM on POSTed systems
  - a412d582: Read PCI BIOS on secondary R5xx cards

* Thu Jan 03 2008 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.3.20080103git
- New snapshot (upstream commit 4e488a349c862da2e27f6025d376fb2b63db3bf9):
  - Enable FB location fix for r5xx.
  - Fix PLLControlTableRetrieve() loop.

* Fri Dec 28 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.0-0.2.20071228git
- New snapshot (upstream commit fcf15c8facb7c2c1a4a2513f3f84537f3f35c6a1):
  - (Some?) RV670 support
  - c036b819: Only report unknown cards IF they have issues.
  - b9277bfc: Check for loaded fglrx kernel module.
  - 765f5972: Man page describes all RandR properties
  - 2b3928c6: Fix "messed up colours" issues after suspend/resume
  - ...

* Wed Dec 19 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.4.20071219git
- New snapshot (upstream commit 861debbf8d649ce09d53d5880f819757ac9c7814)
  - 861debbf: Make the driver build with the latest ustream git server sources again.
  - 9120f95f: Delete a spurious git_version.h.new when doing make clean.
  - e98195bd: Don't fail immediately when git-rev-parse fails.
  - 6d9a6709: IDs: Asus M2A-VM should now no longer need a connector table.
  - 521bcace: DxGRPH: Fix graphics engine colour issues (hopefully).
  - 47f8a6f7: Add support for HDMI connectors.
  - 21e1c6c4: Get EDID block for panels from AtomBIOS even if there is a special Mode.
  - 492e94c3: LVDS: Fix 18/24 bit dithering and disable spatial dither.
  - 55f89f69: LVDS: Fix FPDI handling.
  - ef51931a: HPD pin swapping logic.
  - 9741c5be: TMDSA: properly add macro control for 0x7149 (M56)
  - dcfd91c2: TMDSA/B: add macro control values for 0x71C6 (RV530)
  - c784c92a: TMDSA: add macro control for 0x7147 (M56)
  - 5acefe5c: ID: 0x724B: Sapphire Radeon X1900 GT
  - 1a1d110f: Restore: Fix VGA textmode restore when VSYNC length is 0.

* Wed Dec 12 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.3.20071212git
- New snapshot (upstream commit b991fe3d884a51e236f895c41b0ba1b06127f7dd):
  - b991fe3d: DACs: Properly set up and save/restore SYNC_SELECT.
  - bb12148c: Added Asus M2A-VM (RS690 based) to quirks table.
  - 87f8f8e9: Add Gigabyte HD 2600 XT to quirks table.
  - b0cb8aec: Don't check for connector type for DMS-59 detection (RandR case).
  - affbdf54: Additional checks for cursor size in UseHWCursor().
  - 09b4dea7: Only reload cursor image if there is one.
  - dc7fe476: Broken connector table: GeCube Radeon HD 2400 AGP: proper fix.
  - ae46a18d: TMDSA/B: 9587 electrical values.
  - 030f715c: Fix 13509: Xserver crash when RandR finds no modes.
  - c01edd52: Improve scanning of panning area specification. Pan to area on setting it.
  - 42a07a0d: Re-create Atoms for properties in CreateResources.
  - 6d0c7c32: Add panning in RandR mode.
- Ship new ChangeLog file.

* Sun Dec 09 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.2.20071209git
- New snapshot (upstream commit e399d16597e30a6c53c8f70aa122285615fe7d08)
  - Fix blank screen occuring in some cases.
  - Initial RS600 support.
  - Sync and LUT fixes.
  - Add useful DPI calculation.
- Relax xorg-x11-server-utils requirement: Only for F-8 and later, no %%{dist}.

* Fri Nov 30 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.0.0-0.1.20071130git
- New snapshot (upstream commit 9fe776edf44c40d06e0059878df4f37391409c66 aka 1.0.0)
  - Significantly improve README and radeonhd(4) man page.
  - Add a number of connector table workarounds.
  - Several messages fixed or toned down.

* Thu Nov 29 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.4-0.2.20071129git
- New snapshot (upstream commit 8b1b8bfb21d2d86780cb4e02abc813578daa24bd):
  - RandR 1.2 support with hotplugging of monitors.
  - R600 LVDS: RS690M, M72, M74 and M76 devices.
  - Fixed "white screen" bug.
  - Numerous fixes and new support for features.
- Preserve source file timestamps where possible.

* Fri Nov 16 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.18.20071116git
- New snapshot (upstream commit dbb073b8b314264e311c3a1ebecd13d93e9627a6):
  - Macbook Pro PCI ID based workaround for awkward AtomBIOS connector table.
  - TMDSA: create a table for electrical adjustments.
- Fix bug submission URL in README.fedora.

* Tue Nov 13 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.17.20071113git
- New snapshot (upstream commit 6f1800ca52531f5baf3df2e65a7bbd93e4b1e637):
  - LVTMA TMDS: Add initial TMDS support for r5xx.
  - TMDS B: Add table with macro control values.
- Loosen requirements on xorg-x11-server-{Xorg,sdk} from 1.3 to 1.1 (FC6, EL5).
- Require pkgconfig for building (not in EL5 default buildroot).
- Adapt references to rhd_conntest in filesystem.
- Fix git:// URL in README.fedora.

* Sun Nov 11 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.16.20071105git
- Updated README.fedora.
- Improved git commit log message.
- First F-7 and F-8 builds.

* Mon Nov 05 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.15.20071105git
- New snapshot (upstream commit e9c24f662860229440dc61ecbae22e7d7c74d442):
  - Improve online help in rhd_conntest.
  - Use correct variable for DDC speed setting on R6xx, fix some warnings.
  - Add git version to program output (we emulate that).
  - Ship rhd_conntest source, and build it (we also install it).

* Tue Oct 31 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.14.20071031git
- New snapshot (upstream commit ad599c4436c64b11d18c89da6a684f5241979a96):
  - Fix 1650Pro PLL gain control.
  - Improve connector handling.
- Stow away radeonhd.xinf generator for possible later use.

* Tue Oct 30 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.13.20071030git
- Do not #include <sys/io.h> in rhd_conntest.c (fix PPC build).

* Tue Oct 30 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.12.20071030git
- New snapshot (upstream commit f3a2530cea981c6b4c88ec85093032ea152ed47f):
  - #include standard headers in corner cases (supposed to fix FC6 build)

* Sun Oct 28 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.11.20071028git
- New snapshot (upstream commit 604bfb02cefa5f56b40aea2dc3256f09836121a4):
  - Added ID for Radeon HD 2600 LE (RV630).
  - Be smarter about the xorg.conf monitor section by selectively ignoring it.
  - Fix mode instability when returning to VT on some mobilities.

* Thu Oct 25 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.10.20071025git
- New snapshot (upstream commit d8cb8a2a8315f86fae0266f58ee30b609c81d510).
- Remove man page patches (man page is upstream now).

* Tue Oct 23 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.9.20071023git
- New snapshot (upstream commit 8699deaba2c920a3df35acfea49360888868becb).
- Add bug report section to README.fedora.

* Sat Oct 20 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.8.20071020git
- New snapshot (upstream commit 3579bdddd95dc6f129e57bcf05cbd8b9b375940f).
- Cleaned up snapshot script.
- Package rhd_conntest utility when building snapshot package.
- Add simple man page.
- Add README.fedora file.

* Wed Oct 17 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.2-0.7.20071017git
- New snapshot (upstream commit d03841b4950b3b827b3c42507e01767d0569391f).
- Use upstream's version 0.0.2.
- Trade in ThinkPad backlight key fix for non-broken mode on lid event.

* Mon Oct 15 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 0.0.1-0.6.20071015git
- Hard-code version at 0.0.1 until upstream have figured out what they want.
- Names of snapshot tarballs now contain timestamp.
- Static definition of %%{date}, optionally updated by snapshot script.
- Non-executable snapshot script.

* Mon Oct 15 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.1-0.5.20071015git
- Use %%{driverdir} where possible.
- Include xorg-x11-drv-radeonhd-snapshot.sh script in SRPM.
- Trimmed Description.
- Removed unnecessary -n from %%files.
- Removed ".fc8" from changelog entries.
- Improved comment on %%define snapshot.

* Mon Oct 15 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.1-0.4.20071015git
- New snapshot (needs less patches).

* Sun Oct 14 2007 Hans Ulrich Niedermann <hun@n-dimensional.de> - 1.1.1-0.3.20071014git
- Initial Fedora RPM package.
